@@ -2,7 +2,7 @@
 #
 # Author: Yipeng Sun
 # License: BSD 2-clause
-# Last Change: Wed Jun 24, 2020 at 09:27 PM +0800
+# Last Change: Wed Aug 05, 2020 at 11:55 PM +0800
 
 import numpy as np
 import tabulate as tabl
@@ -26,7 +26,8 @@ tabl._table_formats["latex_booktabs_raw"] = tabl.TableFormat(
 
 # Find total number of events (unique events) out of total number of candidates.
 def extract_uid(ntp, tree, run_branch='runNumber', event_branch='eventNumber',
-                conditional=None, run_array=None, event_array=None):
+                conditional=None, run_array=None, event_array=None,
+                keep_single_candidate_events_only=False):
     if run_array is None or event_array is None:
         run, event = read_branches(ntp, tree, (run_branch, event_branch))
     else:
@@ -42,18 +43,26 @@ def extract_uid(ntp, tree, run_branch='runNumber', event_branch='eventNumber',
     run = np.char.add(run, '-')
     ids = np.char.add(run, event)
 
-    uid, idx = np.unique(ids, return_index=True)
+    uid, idx, count = np.unique(ids, return_index=True, return_counts=True)
+
+    if keep_single_candidate_events_only:
+        uid = uid[count == 1]
+        idx = idx[count == 1]
 
     total_size = ids.size
-    uniq_size = uid.size  # The size of all IDs that occurred
+    uniq_size = uid.size
     dupl_size = total_size - uniq_size
 
     return uid, idx, total_size, uniq_size, dupl_size
 
 
 def find_common_uid(ntp1, ntp2, tree1, tree2, **kwargs):
-    uid1, idx1, _, _, _ = extract_uid(ntp1, tree1, **kwargs)
-    uid2, idx2, _, _, _ = extract_uid(ntp2, tree2, **kwargs)
+    uid1, idx1, _, _, _ = extract_uid(ntp1, tree1,
+                                      keep_single_candidate_events_only=True,
+                                      **kwargs)
+    uid2, idx2, _, _, _ = extract_uid(ntp2, tree2,
+                                      keep_single_candidate_events_only=True,
+                                      **kwargs)
     uid_comm, uid_comm_idx1, uid_comm_idx2 = np.intersect1d(
         uid1, uid2, assume_unique=True, return_indices=True)
 
